# ValConfig - Contrib

This is a collection of resources which may be used alongside *ValConfig*:

- `HoloConfig`: A specialized `ValConfig` subclass for use with [Holoviews](https://holoviews.org/).
- *paul_tol_colors.cfg*: Some of Paul Tol’s [colour schemes](https://personal.sron.nl/~pault/data/colourschemes.pdf), importable as a config file. Uses [interpolation](https://docs.python.org/3/library/configparser.html#interpolation-of-values) to define the cycles.

Please note that these resources may have different levels of maturity.